@@ -26,6 +26,9 @@
  * OTHER DEALINGS IN THE SOFTWARE.
  */
 
+#ifndef LIB_ARM_CRC32_IMPL_H
+#define LIB_ARM_CRC32_IMPL_H
+
 #include "cpu_features.h"
 
 /* Implementation using ARM CRC32 instructions */
@@ -240,3 +243,5 @@ arch_select_crc32_func(void)
 	return NULL;
 }
 #endif /* DISPATCH */
+
+#endif /* LIB_ARM_CRC32_IMPL_H */
