@@ -25,6 +25,9 @@
  * OTHER DEALINGS IN THE SOFTWARE.
  */
 
+#ifndef LIB_ARM_MATCHFINDER_IMPL_H
+#define LIB_ARM_MATCHFINDER_IMPL_H
+
 #ifdef __ARM_NEON
 #  include <arm_neon.h>
 static forceinline void
@@ -79,3 +82,5 @@ matchfinder_rebase_neon(mf_pos_t *data, size_t size)
 #define matchfinder_rebase matchfinder_rebase_neon
 
 #endif /* __ARM_NEON */
+
+#endif /* LIB_ARM_MATCHFINDER_IMPL_H */
