@@ -28,11 +28,14 @@ typedef s16 mf_pos_t;
 #undef matchfinder_init
 #undef matchfinder_rebase
 #ifdef _aligned_attribute
+#  define MATCHFINDER_ALIGNED _aligned_attribute(MATCHFINDER_MEM_ALIGNMENT)
 #  if defined(__arm__) || defined(__aarch64__)
 #    include "arm/matchfinder_impl.h"
 #  elif defined(__i386__) || defined(__x86_64__)
 #    include "x86/matchfinder_impl.h"
 #  endif
+#else
+#  define MATCHFINDER_ALIGNED
 #endif
 
 /*
